==> em_tasks-0.1.67-py2.py3-none-any.whl: em_tasks/utils/spree/boots_repricer.py <==
# -*- coding: utf-8 -*-

import datetime
import json
import time
import re
import multiprocessing
from multiprocessing.pool import ThreadPool

import click
import dateparser

from em_tasks import logger
from em_tasks.spree.product_util import ProductUtil
from em_tasks.store.store_util import StoreUtil
from em_tasks.utils.spree.base_repricer import SpreeBaseRepricer


class SpreeBootsRepricer(SpreeBaseRepricer):
  def __init__(self, store_code, product_service, price_calculator, ttl=7):
    super(SpreeBootsRepricer, self).__init__()
    self.store = StoreUtil.get_store_by_code(store_code)
    if not self.store:
      return

    credential = json.loads(self.store.api_credential)
    self.product_util = ProductUtil(credential['endpoint'], credential['api_key'], credential.get('api_version', 'v1'))
    # self.product_util = ProductUtil('http://localhost:3000', credential['api_key'], credential.get('api_version', 'v1'))

    self.product_service = product_service
    self.price_calc = price_calculator
    self.indice_name = 'boots_products'
    today = datetime.date.today()
    self.expire_date = today - datetime.timedelta(days=ttl)
    self.pool = ThreadPool(3)

  def run(self):
    batch_size = 250
    products = dict()
    for boots_prod in self.product_util.get_boots_products():
      products[boots_prod['source_product_id']] = boots_prod

      if len(products) < batch_size:
        continue

      self.process_products(products)
      products.clear()

    if products:
      self.process_products(products)
      products = []

    self.pool.close()
    self.pool.join()

  def get_source_variant_id_from_sku(self, sku):
      return sku.replace("_", "-").split("-").pop()

  def get_variant_id(self, product, source_variant):
      for variant in product["variants"]:
          source_variant_id = self.get_source_variant_id_from_sku(variant["sku"])
          if str(source_variant_id) == str(source_variant["variant_id"]):
              return variant["variant_id"]

  def process_products(self, prods):
    product_ids = list(prods.keys())
    products = None
    max_retries = 3
    while max_retries > 0:
      try:
        products = self.product_service.search_products(self.indice_name, product_ids)
        if not isinstance(products, dict):
          logger.info('[ProductService] Temporary unavailable! Wait for 10 seconds to retry.')
          max_retries -= 1
          time.sleep(10)
          continue

        break
      except Exception as e:
        logger.exception(e)
        max_retries -= 1
        time.sleep(3)

    if not products:
      return

    for pid, product in products.items():
      if pid not in prods:
        continue

      prod = prods[pid]

      src_offer = None

      existence = product.get('existence', True)
      # has_only_default_variant = product.get('has_only_default_variant', True)
      has_only_default_variant = True

      try:
        if product['currency'] != 'USD':
          product['price'] = round(float(product['price'].replace("£", "")) / 0.81, 2)
          product['currency'] = 'USD'
      except Exception as e:
        product['price'] = 0
      src_product_price = product.get('price', 0)
      src_shipping_fee = product.get('shipping_fee', 0) or 0
      currency = product.get('currency', None) or 'USD'
      if product['variants']:
          if not existence:
            prod['offer'] = {'price': 0, 'quantity': 0}
          else:
            update_date_s = product.get('date', product.get('time', None))
            if not update_date_s:
              continue

            update_date = None
            try:
              update_date = dateparser.parse(update_date_s).date()
            except:
              pass

            if not update_date or update_date < self.expire_date:
              continue

            for variant in product["variants"]:
                src_offer = {'price': variant["price"] + src_shipping_fee, 'currency': currency}
                offer = self.price_calc.calc_offer(src_offer)
                if offer:
                  if "offer" not in prod:
                    prod["offer"] = {}
                
                  prod['offer'][self.get_variant_id(prod, variant)] = {**dict(offer) ,'src_offer': src_offer }

      else:
          if not existence or not has_only_default_variant or not src_product_price:
            prod['offer'] = {'price': 0, 'quantity': 0}
          else:
            update_date_s = product.get('date', product.get('time', None))
            if not update_date_s:
              continue

            update_date = None
            try:
              update_date = dateparser.parse(update_date_s).date()
            except:
              pass

            if not update_date or update_date < self.expire_date:
              continue

            if not existence or not src_product_price:
              # Out of stock
              src_offer = {'price': src_product_price + src_shipping_fee, 'currency': currency}
            else:
              src_offer = {'price': float(src_product_price) + float(src_shipping_fee), 'currency': currency}

            offer = self.price_calc.calc_offer(src_offer)
            if offer:
              prod['offer'] = dict(offer)
              prod['offer']['src_offer'] = src_offer
            else:
              prod['offer'] = offer

    offers = dict()
    for _, prod in prods.items():
      offers[prod['product_id']] = prod

    if offers:
      store_offers = self.product_util.set_products_offer(offers, self.pool)
      # try:
      #   self.update_gmc_offers(store_offers)
      # except Exception as e:
      #   logger.exception(e)
      #   handles = [store_offer['handle'] for store_offer in store_offers.values() if store_offer['handle']]
      #   logger.warning('[Handles] %s', handles)

==> em_tasks-0.1.72-py2.py3-none-any.whl: em_tasks/utils/spree/boots_repricer.py <==
# -*- coding: utf-8 -*-

import datetime
import json
import time
import re
import multiprocessing
from multiprocessing.pool import ThreadPool

import click
import dateparser

from em_tasks import logger
from em_tasks.spree.product_util import ProductUtil
from em_tasks.store.store_util import StoreUtil
from em_tasks.utils.spree.base_repricer import SpreeBaseRepricer


class SpreeBootsRepricer(SpreeBaseRepricer):
  def __init__(self, store_code, product_service, price_calculator, ttl=14):
    super(SpreeBootsRepricer, self).__init__()
    self.store = StoreUtil.get_store_by_code(store_code)
    if not self.store:
      return

    credential = json.loads(self.store.api_credential)
    self.product_util = ProductUtil(credential['endpoint'], credential['api_key'], credential.get('api_version', 'v1'))
    # self.product_util = ProductUtil('http://localhost:3000', credential['api_key'], credential.get('api_version', 'v1'))

    self.product_service = product_service
    self.price_calc = price_calculator
    self.indice_name = 'boots_products'
    today = datetime.date.today()
    self.expire_date = today - datetime.timedelta(days=ttl)

  def run(self):
    batch_size = 250
    products = dict()
    for boots_prod in self.product_util.get_boots_products():
      products[boots_prod['source_product_id']] = boots_prod

      if len(products) < batch_size:
        continue

      self.process_products(products)
      products.clear()

    if products:
      self.process_products(products)
      products = []

  def process_products(self, prods):
    product_ids = list(prods.keys())
    products = None
    max_retries = 3
    while max_retries > 0:
      try:
        products = self.product_service.search_products(self.indice_name, product_ids)
        if not isinstance(products, dict):
          logger.info('[ProductService] Temporary unavailable! Wait for 10 seconds to retry.')
          max_retries -= 1
          time.sleep(10)
          continue

        break
      except Exception as e:
        logger.exception(e)
        max_retries -= 1
        time.sleep(3)

    if not products:
      return

    for pid, product in products.items():
      if pid not in prods:
        continue

      prod = prods[pid]

      src_offer = None

      existence = product.get('existence', True)
      has_only_default_variant = product.get('has_only_default_variant', True)
      if has_only_default_variant is None:
        has_only_default_variant = True

      try:
        if product['currency'] != 'USD':
          product['price'] = round(float(product['price'].replace("£", "")) / 0.81, 2)
          product['currency'] = 'USD'
      except Exception as e:
        product['price'] = 0
      src_product_price = product.get('price', 0)
      src_shipping_fee = product.get('shipping_fee', 0) or 0
      currency = product.get('currency', None) or 'USD'
      if not existence or not has_only_default_variant or not src_product_price:
        prod['offer'] = {'price': 0, 'quantity': 0}
      else:
        update_date_s = product.get('date', product.get('time', None))
        if not update_date_s:
          continue

        update_date = None
        try:
          update_date = dateparser.parse(update_date_s).date()
        except:
          pass

        if not update_date or update_date < self.expire_date:
          prod['offer'] = {'price': 0, 'quantity': 0}
          continue

        src_offer = {'price': float(src_product_price) + float(src_shipping_fee), 'currency': currency}

        offer = self.price_calc.calc_offer(src_offer)
        if offer:
          prod['offer'] = dict(offer)
          prod['offer']['src_offer'] = src_offer
        else:
          prod['offer'] = offer

    offers = dict()
    for _, prod in prods.items():
      offers[prod['product_id']] = prod

    if offers:
      store_offers = self.product_util.set_products_offer(offers, None)
